summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlan Coopersmith <alan.coopersmith@oracle.com>2022-01-30 09:54:31 -0800
committerAlan Coopersmith <alan.coopersmith@oracle.com>2022-01-30 10:29:06 -0800
commit962b8a15a481121ac731431b5be699588d05aa38 (patch)
treee234d653d1dede23fb47070667fe6c05b58912f5
parente4d0f5ff82b2c16fac5c763575b251a2180fcdb8 (diff)
Fix spelling/wording issues
Found by using: codespell --builtin clear,rare,usage,informal,code,names Signed-off-by: Alan Coopersmith <alan.coopersmith@oracle.com>
-rw-r--r--README.md2
-rw-r--r--src/xg47_accel.c4
-rw-r--r--src/xg47_cmdlist.c6
-rw-r--r--src/xg47_i2c.c2
-rw-r--r--src/xg47_mode.c4
-rw-r--r--src/xg47_mode.h2
-rw-r--r--src/xg47_tv.c4
-rw-r--r--src/xg47_videohw.c2
-rw-r--r--src/xgi.h2
-rw-r--r--src/xgi_driver.c4
-rw-r--r--src/xgi_hwmc.c4
-rw-r--r--src/xgi_option.c2
12 files changed, 19 insertions, 19 deletions
diff --git a/README.md b/README.md
index c48f6d3..39adc32 100644
--- a/README.md
+++ b/README.md
@@ -6,7 +6,7 @@ Xorg mailing list:
https://lists.x.org/mailman/listinfo/xorg
-The master development code repository can be found at:
+The primary development code repository can be found at:
https://gitlab.freedesktop.org/xorg/driver/xf86-video-xgixp
diff --git a/src/xg47_accel.c b/src/xg47_accel.c
index 09268ac..81086da 100644
--- a/src/xg47_accel.c
+++ b/src/xg47_accel.c
@@ -142,7 +142,7 @@ static void XG47SubsequentScreenToScreenColorExpandFill(ScrnInfoPtr pScrn,
int skipleft);
*/
-/* CPU to Screen Color expansion - similiar to XAAImageWrite() */
+/* CPU to Screen Color expansion - similar to XAAImageWrite() */
/*
static void XG47SetupForCPUToScreenColorExpandFill(ScrnInfoPtr pScrn,
int fg, int bg,
@@ -326,7 +326,7 @@ Bool XG47AccelInit(ScreenPtr pScreen)
}
XGIDebug(DBG_FUNCTION, "[DBG] Jong 06142006-After XG47InitCmdList\n");
- /* We always use patten bank0 since HW can not handle patten bank swapping corretly! */
+ /* We always use pattern bank0 since HW can not handle pattern bank swapping correctly! */
accel_info.engineFlag = FER_EN_PATTERN_FLIP;
/* ENINT; 32bpp */
accel_info.engineCmd = 0x8200;
diff --git a/src/xg47_i2c.c b/src/xg47_i2c.c
index ae8e9cd..6082076 100644
--- a/src/xg47_i2c.c
+++ b/src/xg47_i2c.c
@@ -183,7 +183,7 @@ xg47_i2c_GetByte(I2CDevPtr d, I2CByte *data, Bool last)
/**
- * Signal devices that a transation has finished
+ * Signal devices that a transaction has finished
*/
static void
xg47_i2c_Stop(I2CDevPtr d)
diff --git a/src/xg47_mode.c b/src/xg47_mode.c
index 8b6a85a..7dd3bc3 100644
--- a/src/xg47_mode.c
+++ b/src/xg47_mode.c
@@ -38,7 +38,7 @@
int g_DualViewMode=0;
-void XG47LoadPalette(ScrnInfoPtr pScrn, int numColors, int *indicies,
+void XG47LoadPalette(ScrnInfoPtr pScrn, int numColors, int *indices,
LOCO *colors, VisualPtr pVisual)
{
vgaHWPtr pVgaHW = VGAHWPTR(pScrn);
@@ -47,7 +47,7 @@ void XG47LoadPalette(ScrnInfoPtr pScrn, int numColors, int *indicies,
for(i = 0; i < numColors; i++)
{
- index = indicies[i];
+ index = indices[i];
OUTB(0x3C6, 0xFF);
DACDelay(pVgaHW);
OUTB(0x3c8, index);
diff --git a/src/xg47_mode.h b/src/xg47_mode.h
index 4a8c790..5686e1e 100644
--- a/src/xg47_mode.h
+++ b/src/xg47_mode.h
@@ -28,7 +28,7 @@
#ifndef _XG47_MODE_H_
#define _XG47_MODE_H_
-extern void XG47LoadPalette(ScrnInfoPtr pScrn, int numColors, int *indicies,
+extern void XG47LoadPalette(ScrnInfoPtr pScrn, int numColors, int *indices,
LOCO *colors, VisualPtr pVisual);
extern void XG47SetOverscan(ScrnInfoPtr pScrn, int overscan);
extern unsigned int XG47DDCRead(ScrnInfoPtr pScrn);
diff --git a/src/xg47_tv.c b/src/xg47_tv.c
index 3fafb62..fea383d 100644
--- a/src/xg47_tv.c
+++ b/src/xg47_tv.c
@@ -694,7 +694,7 @@ unsigned long XG47DetectTVConnection(XGIPtr pXGI)
if (path & 2)
{
/*
- * Because default of TV ouput is on, TV will will see the signal by set 3x5.d7.
+ * Because default of TV output is on, TV will will see the signal by set 3x5.d7.
* So we need turn off TV output if TV is not current device.
*/
XG47SetExternalRegister(pXGI, 0xa0, tv_a0 | 8);
@@ -743,7 +743,7 @@ unsigned long XG47DetectTVConnection(XGIPtr pXGI)
* void InitTVScreen(CARD16 xRes, CARD16 yRes, CARD16 color, CARD16 attr)
* Initial TV screen after set mode.
* xRes: Resolution, Width
- * yRes: Resolution, Hight
+ * yRes: Resolution, Height
* color: color depth(8, 16 or 32bit)
* Attr: Mode sub info
*/
diff --git a/src/xg47_videohw.c b/src/xg47_videohw.c
index 1daffef..6efd25b 100644
--- a/src/xg47_videohw.c
+++ b/src/xg47_videohw.c
@@ -37,7 +37,7 @@
#include "xgi_misc.h"
/*
- * HW Regs Setting from blow function
+ * HW Regs Setting from below function
*/
void XG47WaitForSync(ScrnInfoPtr pScrn)
{
diff --git a/src/xgi.h b/src/xgi.h
index e122f1c..10bc6b3 100644
--- a/src/xgi.h
+++ b/src/xgi.h
@@ -372,7 +372,7 @@ typedef struct {
* : CARD16, CARD16 - Save the BIOS default value
* : CARD8 - Total swing width
* : CARD8 - Logical default value
- * : CARD8 - Current offset (Registery save value)
+ * : CARD8 - Current offset (Registry save value)
* : CARD8 - Delta
* 0----------------+----------|----------N
* Bios default defoffset Curoffset
diff --git a/src/xgi_driver.c b/src/xgi_driver.c
index b440e85..43a2d76 100644
--- a/src/xgi_driver.c
+++ b/src/xgi_driver.c
@@ -1375,7 +1375,7 @@ Bool XGIPreInit(ScrnInfoPtr pScrn, int flags)
/* Check the number of entities registered for the screen against the expected
* number (most drivers expect only one).The entity information for
* each of them should be retrieved by calling xf86GetEntityInfo()).
- * And check for the correct bus type and that none of the sharable
+ * And check for the correct bus type and that none of the shareable
* resources registered during the Probe phase was rejected.
*/
@@ -1689,7 +1689,7 @@ Bool XGIFBManagerInit(ScreenPtr pScreen)
availFBArea.y2 = (temp > 2047) ? 2047 : temp;
- /* XAA uses FB manager for its pixmap cahe */
+ /* XAA uses FB manager for its pixmap cache */
ret = xf86InitFBManager(pScreen, &availFBArea);
#if DBG_FLOW
diff --git a/src/xgi_hwmc.c b/src/xgi_hwmc.c
index 942a31b..9cce243 100644
--- a/src/xgi_hwmc.c
+++ b/src/xgi_hwmc.c
@@ -123,7 +123,7 @@ static XF86ImagePtr XGISubpictureList[2] =
/* Fill in the device dependent adaptor record.
* This is named "XGI Video Overlay" because this code falls under the
- * XV extenstion, the name must match or it won't be used.
+ * XV extension, the name must match or it won't be used.
*
* Surface and Subpicture - see above
* Function pointers to functions below
@@ -152,7 +152,7 @@ static XF86MCAdaptorPtr ppAdaptor[1] =
*
* XGIInitMC
*
- * Initialize the hardware motion compenstation extention for this
+ * Initialize the hardware motion compensation extension for this
* hardware. The initialization routines want the address of the pointers
* to the structures, not the address of the structures. This means we
* allocate (or create static?) the pointer memory and pass that
diff --git a/src/xgi_option.c b/src/xgi_option.c
index 280692e..3ee39f6 100644
--- a/src/xgi_option.c
+++ b/src/xgi_option.c
@@ -155,7 +155,7 @@ Bool XGIProcessOptions(ScrnInfoPtr pScrn)
pXGI->displayDevice = 0;
- /* Jong 11/09/2006; pXGI->displayDevice is still 0 after this cheking */
+ /* Jong 11/09/2006; pXGI->displayDevice is still 0 after this checking */
if ((s = xf86GetOptValString(pXGI->pOptionInfo, OPTION_DISPLAY)))
{
if(!xf86NameCmp(s, "CRT"))
diff --git a/src/xg47_cmdlist.c b/src/xg47_cmdlist.c
index 1f8374c..3d7b98d 100644
--- a/src/xg47_cmdlist.c
+++ b/src/xg47_cmdlist.c
@@ -47,7 +47,7 @@ struct xg47_batch {
* batch.
*/
uint32_t * begin; /**< Pointer to first command of batch. */
- uint32_t * end; /**< Pointer for writing next coomand */
+ uint32_t * end; /**< Pointer for writing next command */
};
@@ -72,7 +72,7 @@ struct xg47_CmdList
/**
* \name 2D Command bunch
*
- * Buffer indiviual 2D command register writes.
+ * Buffer individual 2D command register writes.
*/
/*@{*/
unsigned bunch_count; /**< Number of commands pending in \c bunch. */
@@ -203,7 +203,7 @@ xg47_wait_fence(int fd, uint32_t fence)
int xg47_BeginCmdListType(struct xg47_CmdList *pCmdList, unsigned req_size,
unsigned type)
{
/* Pad the commmand list to 128-bit alignment and add the begin header.
*/
const unsigned size = ((req_size + 0x3) & ~0x3) + AGPCMDLIST_BEGIN_SIZE;
const uint32_t *const mid_point =
@@ -203,7 +203,7 @@ xg47_wait_fence(int fd, uint32_t fence)
unsigned type)
{
- /* Pad the commmand list to 128-bit alignment and add the begin header.
+ /* Pad the command list to 128-bit alignment and add the begin header.
*/
const unsigned size = ((req_size + 0x3) & ~0x3) + AGPCMDLIST_BEGIN_SIZE;